==> glue-1.93.0-sources.jar: software/amazon/awscdk/services/glue/SerializationLibrary.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) Serialization library to use when serializing/deserializing (SerDe) table records.
 * <p>
 * @see https://cwiki.apache.org/confluence/display/Hive/SerDe
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.487Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.SerializationLibrary")
public class SerializationLibrary extends software.amazon.jsii.JsiiObject {

    protected SerializationLibrary(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SerializationLibrary(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AVRO = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "AVRO", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        CLOUDTRAIL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "CLOUDTRAIL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        GROK = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "GROK", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        HIVE_JSON = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "HIVE_JSON", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        LAZY_SIMPLE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "LAZY_SIMPLE", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        OPEN_CSV = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "OPEN_CSV", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        OPENX_JSON = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "OPENX_JSON", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        ORC = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "ORC", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        PARQUET = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "PARQUET", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        REGEXP = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "REGEXP", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
    }

    /**
     * @param className This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SerializationLibrary(final @org.jetbrains.annotations.NotNull java.lang.String className) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(className, "className is required") });
    }

    /**
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/avro/AvroSerDe.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary AVRO;

    /**
     * @see https://docs.aws.amazon.com/athena/latest/ug/cloudtrail.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary CLOUDTRAIL;

    /**
     * @see https://docs.aws.amazon.com/athena/latest/ug/grok.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary GROK;

    /**
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hive/hcatalog/data/JsonSerDe.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary HIVE_JSON;

    /**
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/lazy/LazySimpleSerDe.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary LAZY_SIMPLE;

    /**
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/OpenCSVSerde.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary OPEN_CSV;

    /**
     * @see https://github.com/rcongiu/Hive-JSON-Serde
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary OPENX_JSON;

    /**
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/orc/OrcSerde.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary ORC;

    /**
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/parquet/serde/ParquetHiveSerDe.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary PARQUET;

    /**
     * @see https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/RegexSerDe.html
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary REGEXP;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getClassName() {
        return software.amazon.jsii.Kernel.get(this, "className", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> glue-1.182.0-sources.jar: software/amazon/awscdk/services/glue/SerializationLibrary.java <==
package software.amazon.awscdk.services.glue;

/**
 * (experimental) Serialization library to use when serializing/deserializing (SerDe) table records.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.glue.*;
 * SerializationLibrary serializationLibrary = SerializationLibrary.AVRO;
 * </pre></blockquote>
 * <p>
 * @see <a href="https://cwiki.apache.org/confluence/display/Hive/SerDe">https://cwiki.apache.org/confluence/display/Hive/SerDe</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:43.478Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.glue.$Module.class, fqn = "@aws-cdk/aws-glue.SerializationLibrary")
public class SerializationLibrary extends software.amazon.jsii.JsiiObject {

    protected SerializationLibrary(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SerializationLibrary(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AVRO = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "AVRO", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        CLOUDTRAIL = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "CLOUDTRAIL", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        GROK = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "GROK", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        HIVE_JSON = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "HIVE_JSON", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        LAZY_SIMPLE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "LAZY_SIMPLE", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        OPEN_CSV = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "OPEN_CSV", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        OPENX_JSON = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "OPENX_JSON", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        ORC = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "ORC", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        PARQUET = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "PARQUET", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
        REGEXP = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.glue.SerializationLibrary.class, "REGEXP", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.glue.SerializationLibrary.class));
    }

    /**
     * @param className This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public SerializationLibrary(final @org.jetbrains.annotations.NotNull java.lang.String className) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(className, "className is required") });
    }

    /**
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/avro/AvroSerDe.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/avro/AvroSerDe.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary AVRO;

    /**
     * @see <a href="https://docs.aws.amazon.com/athena/latest/ug/cloudtrail.html">https://docs.aws.amazon.com/athena/latest/ug/cloudtrail.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary CLOUDTRAIL;

    /**
     * @see <a href="https://docs.aws.amazon.com/athena/latest/ug/grok.html">https://docs.aws.amazon.com/athena/latest/ug/grok.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary GROK;

    /**
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hive/hcatalog/data/JsonSerDe.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hive/hcatalog/data/JsonSerDe.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary HIVE_JSON;

    /**
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/lazy/LazySimpleSerDe.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/lazy/LazySimpleSerDe.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary LAZY_SIMPLE;

    /**
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/OpenCSVSerde.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/OpenCSVSerde.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary OPEN_CSV;

    /**
     * @see <a href="https://github.com/rcongiu/Hive-JSON-Serde">https://github.com/rcongiu/Hive-JSON-Serde</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary OPENX_JSON;

    /**
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/orc/OrcSerde.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/orc/OrcSerde.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary ORC;

    /**
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/parquet/serde/ParquetHiveSerDe.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/ql/io/parquet/serde/ParquetHiveSerDe.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary PARQUET;

    /**
     * @see <a href="https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/RegexSerDe.html">https://hive.apache.org/javadocs/r1.2.2/api/org/apache/hadoop/hive/serde2/RegexSerDe.html</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.glue.SerializationLibrary REGEXP;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getClassName() {
        return software.amazon.jsii.Kernel.get(this, "className", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
